@@ -6,4 +6,4 @@ function init() {
         }
     }
 }
-window.onload = init;
+window.onload = init();
